@@ -1,8 +1,9 @@
-from rwkvstic.agnostic.backends.torch import RWKVCudaOps, RWKVPTCompatOps, RWKVPTTSExportOps, RWKVSplitCudaOps, RWKVCudaQuantOps, RWKVStreamBigOps, RWKVCudaDeepspeedOps
+from rwkvstic.agnostic.backends.torch import RWKVCudaOps, RWKVPTTSExportOps, RWKVSplitCudaOps, RWKVCudaQuantOps, RWKVStreamBigOps, RWKVCudaDeepspeedOps
 from rwkvstic.agnostic.backends.jax import RWKVJaxOps, RWKVNumpyOps
 from rwkvstic.agnostic.backends.tensorflow import RWKVTFExport, RWKVTFOps
 from rwkvstic.agnostic.backends.base import module
 from rwkvstic.agnostic.backends.onnx import RWKVOnnxOps
+from rwkvstic.agnostic.backends.coreml import RWKVCoreMLOps
 from typing import Dict
 
 Backends: Dict[str, module] = {
@@ -16,8 +17,8 @@ Backends: Dict[str, module] = {
     "pytorch-split(2xgpu)": RWKVSplitCudaOps,
     "export-torchscript": RWKVPTTSExportOps,
     "export-tensorflow": RWKVTFExport,
-    "pytorch-compatibility(cpu/debug)": RWKVPTCompatOps,
-    "onnx": RWKVOnnxOps
+    "onnx_export": RWKVOnnxOps,
+    # "coreml": RWKVCoreMLOps
 }
 
 
@@ -26,9 +27,10 @@ JAX = "jax(cpu/gpu/tpu)"
 TF = "tensorflow(cpu/gpu)"
 TORCH_DEEPSPEED = "pytorch-deepspeed(gpu)"
 TORCH_QUANT = "pytorch-quant(gpu-8bit)"
-TORCH_STREAM = "pytorch-stream(gpu-config-vram)"
 TORCH_SPLIT = "pytorch-split(2xgpu)"
 TORCH_EXPORT = "export-torchscript"
 TF_EXPORT = "export-tensorflow"
-TORCH_COMPAT = "pytorch-compatibility(cpu/debug)"
+ONNX_EXPORT = "onnx_export"
 NUMPY = "numpy(cpu)"
+
+# COREML = "coreml"
